/**
 * 携帯電話の通話機能群に相当するインタフェース． 要は電話の能力と考えてよい． このインタフェース定義は変更しないでください．
 * 
 * @author kaiya
 * 
 */
public interface Callable {

	/**
	 * ある電話callerからこの電話に電話をかける． 双方がアプリLを有効にしてれば無料通話，それ以外は一律30円かかるものとする．
	 * 無論，電話をかける方，かけられる方のどちらかが通話中の場合は，電話はつながらない．
	 * 
	 * @param caller
	 *            かけたほうの電話
	 * @return つながればCallのインスタンスが返る，つながらないとnullが返る．
	 */
	public Call call(Callable caller);

	/**
	 * この電話のアドレス帳を得る．
	 * 
	 * @return アドレスの配列．もし空なら長さゼロの配列を返す．nullは決して返らない．
	 */
	public Callable[] getAddresses();

	/**
	 * アドレス帳に電話cを登録する． 既に登録済の電話を登録すると偽が返り，特に状態は変化しない． cがnullの場合も偽となり，特に状態は変化しない．
	 * この電話帳には自分自身の電話を登録することはできない．
	 * 
	 * @param c
	 *            登録する電話
	 * @return 登録に成功すれば真，それ以外は偽．
	 */
	public boolean addAddress(Callable c);

	/**
	 * アドレス帳から電話cを削除． 登録していない電話を削除しようとすると偽が返り，特に状態は変化しない．
	 * cがnullの場合も偽となり，特に状態は変化しない．
	 * 
	 * @param c
	 *            削除する電話
	 * @return 成功すれば真，そうでなければ偽．
	 */
	public boolean removeAddress(Callable c);

	/**
	 * 電話料金の累計．リセットの手段は無いので，シュミレーション中の全累計としてよい．
	 * 
	 * @return 電話料金の累計．
	 */
	public int getTotalCharge();

	/**
	 * 電話番号を返す．
	 * 
	 * @return 単純化のため電話番号は単なる整数，例えば，256 等とする．
	 */
	public int getNumber();
}
