/**
 * 電話番号をIDとしてIP等経由で電話を無料でかけるアプリケーションが有する機能群を表すインタフェース． このインタフェース定義は変更しないでください．
 * 
 * @author kaiya
 * 
 */
public interface Linable {
	/**
	 * 当該アプリケーションが有効か否かを照会
	 * 
	 * @return 有効なら真，無効もしくはインストールされていなければ偽を返す．
	 */
	public boolean isActiveLine();

	/**
	 * 当該アプリを有効にする．
	 */
	public void activateLine();

	/**
	 * 当該アプリを無効化する．
	 */
	public void inactivateLine();

	/**
	 * アドレス帳にあるアドレスの中で無料通話可能なアドレスのリストを返す． まずは自身がアプリLを有効にしていないとリストは長さゼロの配列である．
	 * 加えて，相手も同時にアプリLを有効にしていて，はじめて，無料通話可能なアドレスとなり，当該リストに追加される．
	 * アドレス帳自体，更新されるし，自身やアドレス帳にのってる人がアプリLを有効にするか，無効にするかも常時変わってくるので， そのことを考慮してね．
	 * 
	 * @return 無料通話可能な電話のリスト．無料通話可能なアドレスが無い場合，長さゼロの配列を返す．決してnullは返らない．
	 */
	public Callable[] getFreeAddresses();
}
